@@ -73,7 +73,7 @@ class CronJob:
         return
 
 
-def registerCronJob(cronjob: CronJob):
+def register_cron_job(cronjob: CronJob):
     global _CRONJOBS, _MANAGER, _UPDATE_INTERVAL
     if type(cronjob.interval) is int and cronjob.interval < _UPDATE_INTERVAL:
         _UPDATE_INTERVAL = cronjob.interval
@@ -87,3 +87,8 @@ def registerCronJob(cronjob: CronJob):
                 time.sleep(_UPDATE_INTERVAL)
         _MANAGER = Thread(target=_manager)
         _MANAGER.start()
+
+
+# --- deprecated --- #
+registerCronJob = register_cron_job
+# --- deprecated --- #
