@@ -224,7 +224,7 @@ class Server:
     def sendToClientID(self, clientID, data):
         for client in self.clients:
             if client["clientID"] == clientID:
-                self.sendTo(clientID["clientSocket"], data)
+                self.sendTo(client["clientSocket"], data)
 
     def close(self):
         self.serverSocket.close()
